module.exports = defineTest({
	description: 'does not retain side-effect-free code in functions called from try-statement-blocks'
});
